Service

Struct Service 

pub struct Service { /* private fields */ }
Service wrapper for uniffi bindings

Implementations

Source

impl Service

pub fn inner(&self) -> Arc<SlimService>

Get a clone of the inner service Arc for advanced use cases

Source

impl Service

pub fn new(name: String) -> Self

Create a new Service with the given name

pub fn new_with_config(name: String, config: ServiceConfig) -> Self

Create a new Service with configuration

pub fn config(&self) -> ServiceConfig

Get the service configuration

pub fn get_name(&self) -> String

Get the service identifier/name

pub async fn run_async(&self) -> Result<(), SlimError>

Run the service (starts all configured servers and clients)

pub fn run(&self) -> Result<(), SlimError>

Run the service (starts all configured servers and clients) - blocking version

pub async fn shutdown_async(&self) -> Result<(), SlimError>

Shutdown the service gracefully

pub fn shutdown(&self) -> Result<(), SlimError>

Shutdown the service gracefully - blocking version

pub async fn run_server_async( &self, config: ServerConfig, ) -> Result<(), SlimError>

Start a server with the given configuration

pub fn run_server(&self, config: ServerConfig) -> Result<(), SlimError>

Start a server with the given configuration - blocking version

pub fn stop_server(&self, endpoint: String) -> Result<(), SlimError>

Stop a server by endpoint - blocking version

pub async fn connect_async( &self, config: ClientConfig, ) -> Result<u64, SlimError>

Connect to a remote endpoint as a client

pub fn connect(&self, config: ClientConfig) -> Result<u64, SlimError>

Connect to a remote endpoint as a client - blocking version

pub fn disconnect(&self, conn_id: u64) -> Result<(), SlimError>

Disconnect a client connection by connection ID - blocking version

pub fn get_connection_id(&self, endpoint: String) -> Option<u64>

Get the connection ID for a given endpoint

pub async fn create_app_async( &self, base_name: Arc<Name>, identity_provider_config: IdentityProviderConfig, identity_verifier_config: IdentityVerifierConfig, ) -> Result<Arc<App>, SlimError>

Create a new App with authentication configuration (async version)

This method initializes authentication providers/verifiers and creates a App on this service instance.

Arguments
  • base_name - The base name for the app (without ID)
  • identity_provider_config - Configuration for proving identity to others
  • identity_verifier_config - Configuration for verifying identity of others
Returns
  • Ok(Arc<App>) - Successfully created adapter
  • Err(SlimError) - If adapter creation fails
pub async fn create_app_with_direction_async( &self, name: Arc<Name>, identity_provider_config: IdentityProviderConfig, identity_verifier_config: IdentityVerifierConfig, direction: Direction, ) -> Result<Arc<App>, SlimError>

Create a new App with authentication configuration and traffic direction (async version)

This method initializes authentication providers/verifiers and creates an App on this service instance. The direction parameter controls whether the app can send messages, receive messages, both, or neither.

Arguments
  • base_name - The base name for the app (without ID)
  • identity_provider_config - Configuration for proving identity to others
  • identity_verifier_config - Configuration for verifying identity of others
  • direction - Traffic direction: Send, Recv, Bidirectional, or None
Returns
  • Ok(Arc<App>) - Successfully created adapter
  • Err(SlimError) - If adapter creation fails
pub async fn create_app_with_secret_async( &self, name: Arc<Name>, secret: String, ) -> Result<Arc<App>, SlimError>

Create a new App with SharedSecret authentication (async version)

This is a convenience function for creating a SLIM application using SharedSecret authentication on this service instance. This is the async version.

Arguments
  • name - The base name for the app (without ID)
  • secret - The shared secret string for authentication
Returns
  • Ok(Arc<App>) - Successfully created app
  • Err(SlimError) - If app creation fails
pub fn create_app( &self, base_name: Arc<Name>, identity_provider_config: IdentityProviderConfig, identity_verifier_config: IdentityVerifierConfig, ) -> Result<Arc<App>, SlimError>

Create a new App with authentication configuration (blocking version)

This method initializes authentication providers/verifiers and creates a App on this service instance. This is a blocking wrapper around create_app_async.

Arguments
  • base_name - The base name for the app (without ID)
  • identity_provider_config - Configuration for proving identity to others
  • identity_verifier_config - Configuration for verifying identity of others
Returns
  • Ok(Arc<App>) - Successfully created adapter
  • Err(SlimError) - If adapter creation fails
pub fn create_app_with_direction( &self, base_name: Arc<Name>, identity_provider_config: IdentityProviderConfig, identity_verifier_config: IdentityVerifierConfig, direction: Direction, ) -> Result<Arc<App>, SlimError>

Create a new App with authentication configuration and traffic direction (blocking version)

This method initializes authentication providers/verifiers and creates an App on this service instance. The direction parameter controls whether the app can send messages, receive messages, both, or neither.

Arguments
  • base_name - The base name for the app (without ID)
  • identity_provider_config - Configuration for proving identity to others
  • identity_verifier_config - Configuration for verifying identity of others
  • direction - Traffic direction: Send, Recv, Bidirectional, or None
Returns
  • Ok(Arc<App>) - Successfully created adapter
  • Err(SlimError) - If adapter creation fails
pub fn create_app_with_secret( &self, name: Arc<Name>, secret: String, ) -> Result<Arc<App>, SlimError>

Create a new App with SharedSecret authentication (helper function)

This is a convenience function for creating a SLIM application using SharedSecret authentication on this service instance.

Arguments
  • name - The base name for the app (without ID)
  • secret - The shared secret string for authentication
Returns
  • Ok(Arc<App>) - Successfully created app
  • Err(SlimError) - If app creation fails